# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ct.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ct.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n\x08\x63t.proto\x12\x07zsearch\"\xb2\x01\n\x0e\x43TServerStatus\x12\r\n\x05index\x18\x01 \x01(\x03\x12\x14\n\x0c\x63t_timestamp\x18\x02 \x01(\x03\x12\x16\n\x0epull_timestamp\x18\x03 \x01(\x03\x12\x16\n\x0epush_timestamp\x18\x04 \x01(\x03\x12*\n\x0bpush_status\x18\x05 \x01(\x0e\x32\x15.zsearch.CTPushStatus\x12\x0b\n\x03sct\x18\x06 \x01(\x0c\x12\x12\n\npush_error\x18\x07 \x01(\t\"\x87\r\n\x08\x43TStatus\x12+\n\ncensys_dev\x18\x01 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\'\n\x06\x63\x65nsys\x18\x02 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0egoogle_aviator\x18\n \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0cgoogle_pilot\x18\x0b \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x31\n\x10google_rocketeer\x18\x0c \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x32\n\x11google_submariner\x18\r \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x30\n\x0fgoogle_testtube\x18\x0e \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12.\n\rgoogle_icarus\x18\x0f \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x30\n\x0fgoogle_skydiver\x18\x10 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x30\n\x0fgoogle_daedalus\x18\x11 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0c\x64igicert_ct1\x18\x14 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0c\x64igicert_ct2\x18( \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12.\n\rizenpe_com_ct\x18\x15 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12.\n\rizenpe_eus_ct\x18\x16 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0esymantec_ws_ct\x18\x17 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x31\n\x10symantec_ws_vega\x18\x18 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x33\n\x12symantec_ws_sirius\x18% \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x32\n\x11symantec_ws_deneb\x18  \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12,\n\x0b\x63omodo_dodo\x18\" \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0e\x63omodo_mammoth\x18# \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0c\x63omodo_sabre\x18) \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12-\n\x0cwosign_ctlog\x18\x19 \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12*\n\twosign_ct\x18\x1a \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12(\n\x07gdca_ct\x18\x1c \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12+\n\ngdca_ctlog\x18$ \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x31\n\x10venafi_api_ctlog\x18\x1f \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x36\n\x15venafi_api_ctlog_gen2\x18\' \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x33\n\x12nordu_ct_plausible\x18! \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12/\n\x0e\x63nnic_ctserver\x18\x1b \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12,\n\x0bstartssl_ct\x18\x1d \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12+\n\ncertly_log\x18\x1e \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12)\n\x08sheca_ct\x18* \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12>\n\x1d\x63\x65rtificatetransparency_cn_ct\x18& \x01(\x0b\x32\x17.zsearch.CTServerStatus\x12\x36\n\x15letsencrypt_ct_clicky\x18+ \x01(\x0b\x32\x17.zsearch.CTServerStatus\"c\n\x03SCT\x12\x10\n\x08sha256fp\x18\x01 \x01(\x0c\x12!\n\x06server\x18\x02 \x01(\x0e\x32\x11.zsearch.CTServer\x12\'\n\x06status\x18\x03 \x01(\x0b\x32\x17.zsearch.CTServerStatus*\xeb\x01\n\x0c\x43TPushStatus\x12\x1b\n\x17\x43T_PUSH_STATUS_RESERVED\x10\x00\x12\x1a\n\x16\x43T_PUSH_STATUS_UNKNOWN\x10\x01\x12\x1a\n\x16\x43T_PUSH_STATUS_SUCCESS\x10\x02\x12 \n\x1c\x43T_PUSH_STATUS_UNKNOWN_ERROR\x10\x03\x12\x1f\n\x1b\x43T_PUSH_STATUS_INVALID_ROOT\x10\x04\x12!\n\x1d\x43T_PUSH_STATUS_ALREADY_EXISTS\x10\x05\x12 \n\x1c\x43T_PUSH_STATUS_WILL_NOT_PUSH\x10\x06*\xac\x08\n\x08\x43TServer\x12\x16\n\x12\x43T_SERVER_RESERVED\x10\x00\x12\x1f\n\x1b\x43T_SERVER_CENSYS_PRODUCTION\x10\x01\x12 \n\x1c\x43T_SERVER_CENSYS_DEVELOPMENT\x10\x02\x12\x1a\n\x16\x43T_SERVER_GOOGLE_PILOT\x10\x0b\x12\x1e\n\x1a\x43T_SERVER_GOOGLE_ROCKETEER\x10\x0c\x12\x1f\n\x1b\x43T_SERVER_GOOGLE_SUBMARINER\x10\r\x12\x1d\n\x19\x43T_SERVER_GOOGLE_TESTTUBE\x10\x0e\x12\x1b\n\x17\x43T_SERVER_GOOGLE_ICARUS\x10\x0f\x12\x1d\n\x19\x43T_SERVER_GOOGLE_SKYDIVER\x10\x10\x12\x1d\n\x19\x43T_SERVER_GOOGLE_DAEDALUS\x10\x11\x12\x1c\n\x18\x43T_SERVER_GOOGLE_AVIATOR\x10\n\x12\x1c\n\x18\x43T_SERVER_SYMANTEC_WS_CT\x10\x17\x12\x1e\n\x1a\x43T_SERVER_SYMANTEC_WS_VEGA\x10\x18\x12\x1f\n\x1b\x43T_SERVER_SYMANTEC_WS_DENEB\x10 \x12 \n\x1c\x43T_SERVER_SYMANTEC_WS_SIRIUS\x10%\x12\x19\n\x15\x43T_SERVER_COMODO_DODO\x10#\x12\x1c\n\x18\x43T_SERVER_COMODO_MAMMOTH\x10$\x12\x1a\n\x16\x43T_SERVER_COMODO_SABRE\x10)\x12\x1a\n\x16\x43T_SERVER_WOSIGN_CTLOG\x10\x19\x12\x17\n\x13\x43T_SERVER_WOSIGN_CT\x10\x1a\x12\x1e\n\x1a\x43T_SERVER_VENAFI_API_CTLOG\x10\x1f\x12#\n\x1f\x43T_SERVER_VENAFI_API_CTLOG_GEN2\x10\'\x12\x15\n\x11\x43T_SERVER_GDCA_CT\x10\x1c\x12\x18\n\x14\x43T_SERVER_GDCA_CTLOG\x10\"\x12\x1b\n\x17\x43T_SERVER_IZENPE_COM_CT\x10\x15\x12\x1b\n\x17\x43T_SERVER_IZENPE_EUS_CT\x10\x16\x12\x1a\n\x16\x43T_SERVER_DIGICERT_CT1\x10\x14\x12\x1a\n\x16\x43T_SERVER_DIGICERT_CT2\x10(\x12\x1c\n\x18\x43T_SERVER_CNNIC_CTSERVER\x10\x1b\x12\x19\n\x15\x43T_SERVER_STARTSSL_CT\x10\x1d\x12\x18\n\x14\x43T_SERVER_CERTLY_LOG\x10\x1e\x12 \n\x1c\x43T_SERVER_NORDU_CT_PLAUSIBLE\x10!\x12+\n\'CT_SERVER_CERTIFICATETRANSPARENCY_CN_CT\x10&\x12\x16\n\x12\x43T_SERVER_SHECA_CT\x10*\x12#\n\x1f\x43T_SERVER_LETSENCRYPT_CT_CLICKY\x10,b\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_CTPUSHSTATUS = _descriptor.EnumDescriptor(
  name='CTPushStatus',
  full_name='zsearch.CTPushStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_SUCCESS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_UNKNOWN_ERROR', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_INVALID_ROOT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_ALREADY_EXISTS', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_PUSH_STATUS_WILL_NOT_PUSH', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1978,
  serialized_end=2213,
)
_sym_db.RegisterEnumDescriptor(_CTPUSHSTATUS)

CTPushStatus = enum_type_wrapper.EnumTypeWrapper(_CTPUSHSTATUS)
_CTSERVER = _descriptor.EnumDescriptor(
  name='CTServer',
  full_name='zsearch.CTServer',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CENSYS_PRODUCTION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CENSYS_DEVELOPMENT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_PILOT', index=3, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_ROCKETEER', index=4, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_SUBMARINER', index=5, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_TESTTUBE', index=6, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_ICARUS', index=7, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_SKYDIVER', index=8, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_DAEDALUS', index=9, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GOOGLE_AVIATOR', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_CT', index=11, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_VEGA', index=12, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_DENEB', index=13, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SYMANTEC_WS_SIRIUS', index=14, number=37,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_COMODO_DODO', index=15, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_COMODO_MAMMOTH', index=16, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_COMODO_SABRE', index=17, number=41,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_WOSIGN_CTLOG', index=18, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_WOSIGN_CT', index=19, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_VENAFI_API_CTLOG', index=20, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_VENAFI_API_CTLOG_GEN2', index=21, number=39,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GDCA_CT', index=22, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_GDCA_CTLOG', index=23, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_IZENPE_COM_CT', index=24, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_IZENPE_EUS_CT', index=25, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_DIGICERT_CT1', index=26, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_DIGICERT_CT2', index=27, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CNNIC_CTSERVER', index=28, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_STARTSSL_CT', index=29, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CERTLY_LOG', index=30, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_NORDU_CT_PLAUSIBLE', index=31, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_CERTIFICATETRANSPARENCY_CN_CT', index=32, number=38,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_SHECA_CT', index=33, number=42,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_SERVER_LETSENCRYPT_CT_CLICKY', index=34, number=44,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2216,
  serialized_end=3284,
)
_sym_db.RegisterEnumDescriptor(_CTSERVER)

CTServer = enum_type_wrapper.EnumTypeWrapper(_CTSERVER)
CT_PUSH_STATUS_RESERVED = 0
CT_PUSH_STATUS_UNKNOWN = 1
CT_PUSH_STATUS_SUCCESS = 2
CT_PUSH_STATUS_UNKNOWN_ERROR = 3
CT_PUSH_STATUS_INVALID_ROOT = 4
CT_PUSH_STATUS_ALREADY_EXISTS = 5
CT_PUSH_STATUS_WILL_NOT_PUSH = 6
CT_SERVER_RESERVED = 0
CT_SERVER_CENSYS_PRODUCTION = 1
CT_SERVER_CENSYS_DEVELOPMENT = 2
CT_SERVER_GOOGLE_PILOT = 11
CT_SERVER_GOOGLE_ROCKETEER = 12
CT_SERVER_GOOGLE_SUBMARINER = 13
CT_SERVER_GOOGLE_TESTTUBE = 14
CT_SERVER_GOOGLE_ICARUS = 15
CT_SERVER_GOOGLE_SKYDIVER = 16
CT_SERVER_GOOGLE_DAEDALUS = 17
CT_SERVER_GOOGLE_AVIATOR = 10
CT_SERVER_SYMANTEC_WS_CT = 23
CT_SERVER_SYMANTEC_WS_VEGA = 24
CT_SERVER_SYMANTEC_WS_DENEB = 32
CT_SERVER_SYMANTEC_WS_SIRIUS = 37
CT_SERVER_COMODO_DODO = 35
CT_SERVER_COMODO_MAMMOTH = 36
CT_SERVER_COMODO_SABRE = 41
CT_SERVER_WOSIGN_CTLOG = 25
CT_SERVER_WOSIGN_CT = 26
CT_SERVER_VENAFI_API_CTLOG = 31
CT_SERVER_VENAFI_API_CTLOG_GEN2 = 39
CT_SERVER_GDCA_CT = 28
CT_SERVER_GDCA_CTLOG = 34
CT_SERVER_IZENPE_COM_CT = 21
CT_SERVER_IZENPE_EUS_CT = 22
CT_SERVER_DIGICERT_CT1 = 20
CT_SERVER_DIGICERT_CT2 = 40
CT_SERVER_CNNIC_CTSERVER = 27
CT_SERVER_STARTSSL_CT = 29
CT_SERVER_CERTLY_LOG = 30
CT_SERVER_NORDU_CT_PLAUSIBLE = 33
CT_SERVER_CERTIFICATETRANSPARENCY_CN_CT = 38
CT_SERVER_SHECA_CT = 42
CT_SERVER_LETSENCRYPT_CT_CLICKY = 44



_CTSERVERSTATUS = _descriptor.Descriptor(
  name='CTServerStatus',
  full_name='zsearch.CTServerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='zsearch.CTServerStatus.index', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct_timestamp', full_name='zsearch.CTServerStatus.ct_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pull_timestamp', full_name='zsearch.CTServerStatus.pull_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_timestamp', full_name='zsearch.CTServerStatus.push_timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_status', full_name='zsearch.CTServerStatus.push_status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sct', full_name='zsearch.CTServerStatus.sct', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='push_error', full_name='zsearch.CTServerStatus.push_error', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=200,
)


_CTSTATUS = _descriptor.Descriptor(
  name='CTStatus',
  full_name='zsearch.CTStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='censys_dev', full_name='zsearch.CTStatus.censys_dev', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='censys', full_name='zsearch.CTStatus.censys', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_aviator', full_name='zsearch.CTStatus.google_aviator', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_pilot', full_name='zsearch.CTStatus.google_pilot', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_rocketeer', full_name='zsearch.CTStatus.google_rocketeer', index=4,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_submariner', full_name='zsearch.CTStatus.google_submariner', index=5,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_testtube', full_name='zsearch.CTStatus.google_testtube', index=6,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_icarus', full_name='zsearch.CTStatus.google_icarus', index=7,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_skydiver', full_name='zsearch.CTStatus.google_skydiver', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_daedalus', full_name='zsearch.CTStatus.google_daedalus', index=9,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='digicert_ct1', full_name='zsearch.CTStatus.digicert_ct1', index=10,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='digicert_ct2', full_name='zsearch.CTStatus.digicert_ct2', index=11,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='izenpe_com_ct', full_name='zsearch.CTStatus.izenpe_com_ct', index=12,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='izenpe_eus_ct', full_name='zsearch.CTStatus.izenpe_eus_ct', index=13,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_ct', full_name='zsearch.CTStatus.symantec_ws_ct', index=14,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_vega', full_name='zsearch.CTStatus.symantec_ws_vega', index=15,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_sirius', full_name='zsearch.CTStatus.symantec_ws_sirius', index=16,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symantec_ws_deneb', full_name='zsearch.CTStatus.symantec_ws_deneb', index=17,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comodo_dodo', full_name='zsearch.CTStatus.comodo_dodo', index=18,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comodo_mammoth', full_name='zsearch.CTStatus.comodo_mammoth', index=19,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comodo_sabre', full_name='zsearch.CTStatus.comodo_sabre', index=20,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wosign_ctlog', full_name='zsearch.CTStatus.wosign_ctlog', index=21,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wosign_ct', full_name='zsearch.CTStatus.wosign_ct', index=22,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gdca_ct', full_name='zsearch.CTStatus.gdca_ct', index=23,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gdca_ctlog', full_name='zsearch.CTStatus.gdca_ctlog', index=24,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='venafi_api_ctlog', full_name='zsearch.CTStatus.venafi_api_ctlog', index=25,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='venafi_api_ctlog_gen2', full_name='zsearch.CTStatus.venafi_api_ctlog_gen2', index=26,
      number=39, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nordu_ct_plausible', full_name='zsearch.CTStatus.nordu_ct_plausible', index=27,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cnnic_ctserver', full_name='zsearch.CTStatus.cnnic_ctserver', index=28,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='startssl_ct', full_name='zsearch.CTStatus.startssl_ct', index=29,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certly_log', full_name='zsearch.CTStatus.certly_log', index=30,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sheca_ct', full_name='zsearch.CTStatus.sheca_ct', index=31,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificatetransparency_cn_ct', full_name='zsearch.CTStatus.certificatetransparency_cn_ct', index=32,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='letsencrypt_ct_clicky', full_name='zsearch.CTStatus.letsencrypt_ct_clicky', index=33,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=1874,
)


_SCT = _descriptor.Descriptor(
  name='SCT',
  full_name='zsearch.SCT',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.SCT.sha256fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server', full_name='zsearch.SCT.server', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='zsearch.SCT.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1876,
  serialized_end=1975,
)

_CTSERVERSTATUS.fields_by_name['push_status'].enum_type = _CTPUSHSTATUS
_CTSTATUS.fields_by_name['censys_dev'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['censys'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_aviator'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_pilot'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_rocketeer'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_submariner'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_testtube'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_icarus'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_skydiver'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['google_daedalus'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['digicert_ct1'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['digicert_ct2'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['izenpe_com_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['izenpe_eus_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_vega'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_sirius'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['symantec_ws_deneb'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['comodo_dodo'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['comodo_mammoth'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['comodo_sabre'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['wosign_ctlog'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['wosign_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['gdca_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['gdca_ctlog'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['venafi_api_ctlog'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['venafi_api_ctlog_gen2'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['nordu_ct_plausible'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['cnnic_ctserver'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['startssl_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['certly_log'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['sheca_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['certificatetransparency_cn_ct'].message_type = _CTSERVERSTATUS
_CTSTATUS.fields_by_name['letsencrypt_ct_clicky'].message_type = _CTSERVERSTATUS
_SCT.fields_by_name['server'].enum_type = _CTSERVER
_SCT.fields_by_name['status'].message_type = _CTSERVERSTATUS
DESCRIPTOR.message_types_by_name['CTServerStatus'] = _CTSERVERSTATUS
DESCRIPTOR.message_types_by_name['CTStatus'] = _CTSTATUS
DESCRIPTOR.message_types_by_name['SCT'] = _SCT
DESCRIPTOR.enum_types_by_name['CTPushStatus'] = _CTPUSHSTATUS
DESCRIPTOR.enum_types_by_name['CTServer'] = _CTSERVER

CTServerStatus = _reflection.GeneratedProtocolMessageType('CTServerStatus', (_message.Message,), dict(
  DESCRIPTOR = _CTSERVERSTATUS,
  __module__ = 'ct_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CTServerStatus)
  ))
_sym_db.RegisterMessage(CTServerStatus)

CTStatus = _reflection.GeneratedProtocolMessageType('CTStatus', (_message.Message,), dict(
  DESCRIPTOR = _CTSTATUS,
  __module__ = 'ct_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CTStatus)
  ))
_sym_db.RegisterMessage(CTStatus)

SCT = _reflection.GeneratedProtocolMessageType('SCT', (_message.Message,), dict(
  DESCRIPTOR = _SCT,
  __module__ = 'ct_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.SCT)
  ))
_sym_db.RegisterMessage(SCT)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: certificate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import common_pb2 as common__pb2
import zlint_pb2 as zlint__pb2
import ct_pb2 as ct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='certificate.proto',
  package='zsearch',
  syntax='proto3',
  serialized_pb=_b('\n\x11\x63\x65rtificate.proto\x12\x07zsearch\x1a\x0c\x63ommon.proto\x1a\x0bzlint.proto\x1a\x08\x63t.proto\"\xc3\x01\n\x0fRootStoreStatus\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x11\n\twas_valid\x18\x02 \x01(\x08\x12\x14\n\x0ctrusted_path\x18\x03 \x01(\x08\x12\x18\n\x10was_trusted_path\x18\x04 \x01(\x08\x12\x13\n\x0b\x62lacklisted\x18\x05 \x01(\x08\x12\x13\n\x0bwhitelisted\x18\x06 \x01(\x08\x12&\n\x04type\x18\x07 \x01(\x0e\x32\x18.zsearch.CertificateType\x12\x0c\n\x04path\x18\x08 \x03(\x0c\"\x9c\x02\n\x15\x43\x65rtificateValidation\x12%\n\x03nss\x18\x01 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12+\n\tmicrosoft\x18\x02 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12\'\n\x05\x61pple\x18\x03 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12&\n\x04java\x18\x04 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12)\n\x07\x61ndroid\x18\x05 \x01(\x0b\x32\x18.zsearch.RootStoreStatus\x12\x33\n\x11google_ct_primary\x18\n \x01(\x0b\x32\x18.zsearch.RootStoreStatus\"\xba\x02\n\x17MozillaSalesForceStatus\x12\x12\n\ncurrent_in\x18\x01 \x01(\x08\x12\x0e\n\x06was_in\x18\x02 \x01(\x08\x12\x12\n\nowner_name\x18\x03 \x01(\t\x12\x13\n\x0bparent_name\x18\x04 \x01(\t\x12\x18\n\x10\x63\x65rtificate_name\x18\x05 \x01(\t\x12\x1a\n\x12\x63\x65rtificate_policy\x18\x06 \x01(\t\x12(\n certification_practice_statement\x18\x07 \x01(\t\x12\x19\n\x11\x63p_same_as_parent\x18\x08 \x01(\x08\x12\x1c\n\x14\x61udit_same_as_parent\x18\t \x01(\x08\x12\x16\n\x0estandard_audit\x18\n \x01(\t\x12\x10\n\x08\x62r_audit\x18\x0b \x01(\t\x12\x0f\n\x07\x61uditor\x18\x0c \x01(\t\"^\n\x15\x43\x65rtificateRevocation\x12\x0f\n\x07revoked\x18\x01 \x01(\x08\x12\x34\n\x06reason\x18\x02 \x01(\x0e\x32$.zsearch.CertificateRevocationReason\"E\n\x10\x43\x65rtificateAudit\x12\x31\n\x07mozilla\x18\x01 \x01(\x0b\x32 .zsearch.MozillaSalesForceStatus\"\xee\t\n\x0b\x43\x65rtificate\x12\x0e\n\x06sha1fp\x18\x01 \x01(\x0c\x12\x10\n\x08sha256fp\x18\x02 \x01(\x0c\x12\x0b\n\x03raw\x18\x03 \x01(\x0c\x12\x0e\n\x06parsed\x18\x04 \x01(\t\x12\x35\n\x0cparse_status\x18, \x01(\x0e\x32\x1f.zsearch.CertificateParseStatus\x12\x15\n\rparse_version\x18\' \x01(\r\x12\x13\n\x0bparse_error\x18/ \x01(\t\x12\x0f\n\x07parents\x18\x05 \x03(\x0c\x12\x17\n\x0fpresented_chain\x18- \x03(\x0c\x12*\n\x06source\x18\x1c \x01(\x0e\x32\x1a.zsearch.CertificateSource\x12\x14\n\x0cseen_in_scan\x18\x1d \x01(\x08\x12\x16\n\x0epost_processed\x18\x1a \x01(\x08\x12\x1e\n\x16post_process_timestamp\x18% \x01(\r\x12\x32\n\nvalidation\x18# \x01(\x0b\x32\x1e.zsearch.CertificateValidation\x12\x1d\n\x02\x63t\x18\x1e \x01(\x0b\x32\x11.zsearch.CTStatus\x12\x1d\n\x05zlint\x18& \x01(\x0b\x32\x0e.zsearch.ZLint\x12\x32\n\nrevocation\x18+ \x01(\x0b\x32\x1e.zsearch.CertificateRevocation\x12(\n\x05\x61udit\x18. \x01(\x0b\x32\x19.zsearch.CertificateAudit\x12\x12\n\nis_precert\x18  \x01(\x08\x12\x17\n\x0fnot_valid_after\x18) \x01(\r\x12\x18\n\x10not_valid_before\x18* \x01(\r\x12\x0e\n\x06in_nss\x18\x06 \x01(\x08\x12\x18\n\x0cin_microsoft\x18\x07 \x01(\x08\x42\x02\x18\x01\x12\x14\n\x08in_apple\x18\x08 \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x14validation_timestamp\x18\n \x01(\r\x12\x15\n\tvalid_nss\x18\x0b \x01(\x08\x42\x02\x18\x01\x12\x1b\n\x0fvalid_microsoft\x18\x0c \x01(\x08\x42\x02\x18\x01\x12\x17\n\x0bvalid_apple\x18\r \x01(\x08\x42\x02\x18\x01\x12\x15\n\rwas_valid_nss\x18\x0e \x01(\x08\x12\x1f\n\x13was_valid_microsoft\x18\x0f \x01(\x08\x42\x02\x18\x01\x12\x1b\n\x0fwas_valid_apple\x18\x10 \x01(\x08\x42\x02\x18\x01\x12\x16\n\nwas_in_nss\x18\x11 \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x10was_in_microsoft\x18\x12 \x01(\x08\x42\x02\x18\x01\x12\x18\n\x0cwas_in_apple\x18\x13 \x01(\x08\x42\x02\x18\x01\x12\x19\n\x11\x63urrent_valid_nss\x18\x14 \x01(\x08\x12#\n\x17\x63urrent_valid_microsoft\x18\x15 \x01(\x08\x42\x02\x18\x01\x12\x1f\n\x13\x63urrent_valid_apple\x18\x16 \x01(\x08\x42\x02\x18\x01\x12\x16\n\x0e\x63urrent_in_nss\x18\x17 \x01(\x08\x12 \n\x14\x63urrent_in_microsoft\x18\x18 \x01(\x08\x42\x02\x18\x01\x12\x1c\n\x10\x63urrent_in_apple\x18\x19 \x01(\x08\x42\x02\x18\x01\x12\x37\n\tnss_audit\x18\x1f \x01(\x0b\x32 .zsearch.MozillaSalesForceStatusB\x02\x18\x01\x12\x1f\n\x13should_post_process\x18\x1b \x01(\x08\x42\x02\x18\x01\x12\x1f\n\x13\x64o_not_post_process\x18$ \x01(\x08\x42\x02\x18\x01*\xa7\x01\n\x0f\x43\x65rtificateType\x12\x1d\n\x19\x43\x45RTIFICATE_TYPE_RESERVED\x10\x00\x12\x1c\n\x18\x43\x45RTIFICATE_TYPE_UNKNOWN\x10\x01\x12\x19\n\x15\x43\x45RTIFICATE_TYPE_LEAF\x10\x02\x12!\n\x1d\x43\x45RTIFICATE_TYPE_INTERMEDIATE\x10\x03\x12\x19\n\x15\x43\x45RTIFICATE_TYPE_ROOT\x10\x04*\xb7\x02\n\x11\x43\x65rtificateSource\x12\x1f\n\x1b\x43\x45RTIFICATE_SOURCE_RESERVED\x10\x00\x12\x1e\n\x1a\x43\x45RTIFICATE_SOURCE_UNKNOWN\x10\x01\x12\x1b\n\x17\x43\x45RTIFICATE_SOURCE_SCAN\x10\x02\x12\x19\n\x15\x43\x45RTIFICATE_SOURCE_CT\x10\x03\x12)\n%CERTIFICATE_SOURCE_MOZILLA_SALESFORCE\x10\x04\x12\x1f\n\x1b\x43\x45RTIFICATE_SOURCE_RESEARCH\x10\x05\x12\x1d\n\x19\x43\x45RTIFICATE_SOURCE_RAPID7\x10\x06\x12\x1d\n\x19\x43\x45RTIFICATE_SOURCE_HUBBLE\x10\x07\x12\x1f\n\x1b\x43\x45RTIFICATE_SOURCE_CT_CHAIN\x10\x08*\xd7\x01\n\x16\x43\x65rtificateParseStatus\x12%\n!CERTIFICATE_PARSE_STATUS_RESERVED\x10\x00\x12$\n CERTIFICATE_PARSE_STATUS_UNKNOWN\x10\x01\x12$\n CERTIFICATE_PARSE_STATUS_SUCCESS\x10\x02\x12!\n\x1d\x43\x45RTIFICATE_PARSE_STATUS_FAIL\x10\x03\x12\'\n#CERTIFICATE_PARSE_STATUS_NOT_PARSED\x10\x04*\xf4\x04\n\x1b\x43\x65rtificateRevocationReason\x12*\n&CERTIFICATE_REVOCATION_REASON_RESERVED\x10\x00\x12)\n%CERTIFICATE_REVOCATION_REASON_UNKNOWN\x10\x01\x12-\n)CERTIFICATE_REVOCATION_REASON_UNSPECIFIED\x10\x02\x12\x30\n,CERTIFICATE_REVOCATION_REASON_KEY_COMPROMISE\x10\x03\x12/\n+CERTIFICATE_REVOCATION_REASON_CA_COMPROMISE\x10\x04\x12\x35\n1CERTIFICATE_REVOCATION_REASON_AFFILIATION_CHANGED\x10\x05\x12,\n(CERTIFICATE_REVOCATION_REASON_SUPERSEDED\x10\x06\x12\x38\n4CERTIFICATE_REVOCATION_REASON_CESSATION_OF_OPERATION\x10\x07\x12\x32\n.CERTIFICATE_REVOCATION_REASON_CERTIFICATE_HOLD\x10\x08\x12\x31\n-CERTIFICATE_REVOCATION_REASON_REMOVE_FROM_CRL\x10\t\x12\x35\n1CERTIFICATE_REVOCATION_REASON_PRIVILEGE_WITHDRAWN\x10\n\x12/\n+CERTIFICATE_REVOCATION_REASON_AA_COMPROMISE\x10\x0b\x62\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,zlint__pb2.DESCRIPTOR,ct__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_CERTIFICATETYPE = _descriptor.EnumDescriptor(
  name='CertificateType',
  full_name='zsearch.CertificateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_LEAF', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_INTERMEDIATE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_TYPE_ROOT', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2302,
  serialized_end=2469,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATETYPE)

CertificateType = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATETYPE)
_CERTIFICATESOURCE = _descriptor.EnumDescriptor(
  name='CertificateSource',
  full_name='zsearch.CertificateSource',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_SCAN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_CT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_MOZILLA_SALESFORCE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_RESEARCH', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_RAPID7', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_HUBBLE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_SOURCE_CT_CHAIN', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2472,
  serialized_end=2783,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATESOURCE)

CertificateSource = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATESOURCE)
_CERTIFICATEPARSESTATUS = _descriptor.EnumDescriptor(
  name='CertificateParseStatus',
  full_name='zsearch.CertificateParseStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_SUCCESS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_FAIL', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_PARSE_STATUS_NOT_PARSED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2786,
  serialized_end=3001,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEPARSESTATUS)

CertificateParseStatus = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATEPARSESTATUS)
_CERTIFICATEREVOCATIONREASON = _descriptor.EnumDescriptor(
  name='CertificateRevocationReason',
  full_name='zsearch.CertificateRevocationReason',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_RESERVED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_UNSPECIFIED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_KEY_COMPROMISE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_CA_COMPROMISE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_AFFILIATION_CHANGED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_SUPERSEDED', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_CESSATION_OF_OPERATION', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_CERTIFICATE_HOLD', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_REMOVE_FROM_CRL', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_PRIVILEGE_WITHDRAWN', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE_REVOCATION_REASON_AA_COMPROMISE', index=11, number=11,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3004,
  serialized_end=3632,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEREVOCATIONREASON)

CertificateRevocationReason = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATEREVOCATIONREASON)
CERTIFICATE_TYPE_RESERVED = 0
CERTIFICATE_TYPE_UNKNOWN = 1
CERTIFICATE_TYPE_LEAF = 2
CERTIFICATE_TYPE_INTERMEDIATE = 3
CERTIFICATE_TYPE_ROOT = 4
CERTIFICATE_SOURCE_RESERVED = 0
CERTIFICATE_SOURCE_UNKNOWN = 1
CERTIFICATE_SOURCE_SCAN = 2
CERTIFICATE_SOURCE_CT = 3
CERTIFICATE_SOURCE_MOZILLA_SALESFORCE = 4
CERTIFICATE_SOURCE_RESEARCH = 5
CERTIFICATE_SOURCE_RAPID7 = 6
CERTIFICATE_SOURCE_HUBBLE = 7
CERTIFICATE_SOURCE_CT_CHAIN = 8
CERTIFICATE_PARSE_STATUS_RESERVED = 0
CERTIFICATE_PARSE_STATUS_UNKNOWN = 1
CERTIFICATE_PARSE_STATUS_SUCCESS = 2
CERTIFICATE_PARSE_STATUS_FAIL = 3
CERTIFICATE_PARSE_STATUS_NOT_PARSED = 4
CERTIFICATE_REVOCATION_REASON_RESERVED = 0
CERTIFICATE_REVOCATION_REASON_UNKNOWN = 1
CERTIFICATE_REVOCATION_REASON_UNSPECIFIED = 2
CERTIFICATE_REVOCATION_REASON_KEY_COMPROMISE = 3
CERTIFICATE_REVOCATION_REASON_CA_COMPROMISE = 4
CERTIFICATE_REVOCATION_REASON_AFFILIATION_CHANGED = 5
CERTIFICATE_REVOCATION_REASON_SUPERSEDED = 6
CERTIFICATE_REVOCATION_REASON_CESSATION_OF_OPERATION = 7
CERTIFICATE_REVOCATION_REASON_CERTIFICATE_HOLD = 8
CERTIFICATE_REVOCATION_REASON_REMOVE_FROM_CRL = 9
CERTIFICATE_REVOCATION_REASON_PRIVILEGE_WITHDRAWN = 10
CERTIFICATE_REVOCATION_REASON_AA_COMPROMISE = 11



_ROOTSTORESTATUS = _descriptor.Descriptor(
  name='RootStoreStatus',
  full_name='zsearch.RootStoreStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='zsearch.RootStoreStatus.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_valid', full_name='zsearch.RootStoreStatus.was_valid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trusted_path', full_name='zsearch.RootStoreStatus.trusted_path', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_trusted_path', full_name='zsearch.RootStoreStatus.was_trusted_path', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blacklisted', full_name='zsearch.RootStoreStatus.blacklisted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='whitelisted', full_name='zsearch.RootStoreStatus.whitelisted', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='zsearch.RootStoreStatus.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='zsearch.RootStoreStatus.path', index=7,
      number=8, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=263,
)


_CERTIFICATEVALIDATION = _descriptor.Descriptor(
  name='CertificateValidation',
  full_name='zsearch.CertificateValidation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nss', full_name='zsearch.CertificateValidation.nss', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='microsoft', full_name='zsearch.CertificateValidation.microsoft', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='apple', full_name='zsearch.CertificateValidation.apple', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='java', full_name='zsearch.CertificateValidation.java', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='android', full_name='zsearch.CertificateValidation.android', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='google_ct_primary', full_name='zsearch.CertificateValidation.google_ct_primary', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=550,
)


_MOZILLASALESFORCESTATUS = _descriptor.Descriptor(
  name='MozillaSalesForceStatus',
  full_name='zsearch.MozillaSalesForceStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_in', full_name='zsearch.MozillaSalesForceStatus.current_in', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_in', full_name='zsearch.MozillaSalesForceStatus.was_in', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_name', full_name='zsearch.MozillaSalesForceStatus.owner_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_name', full_name='zsearch.MozillaSalesForceStatus.parent_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate_name', full_name='zsearch.MozillaSalesForceStatus.certificate_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certificate_policy', full_name='zsearch.MozillaSalesForceStatus.certificate_policy', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='certification_practice_statement', full_name='zsearch.MozillaSalesForceStatus.certification_practice_statement', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cp_same_as_parent', full_name='zsearch.MozillaSalesForceStatus.cp_same_as_parent', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit_same_as_parent', full_name='zsearch.MozillaSalesForceStatus.audit_same_as_parent', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='standard_audit', full_name='zsearch.MozillaSalesForceStatus.standard_audit', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='br_audit', full_name='zsearch.MozillaSalesForceStatus.br_audit', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='auditor', full_name='zsearch.MozillaSalesForceStatus.auditor', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=867,
)


_CERTIFICATEREVOCATION = _descriptor.Descriptor(
  name='CertificateRevocation',
  full_name='zsearch.CertificateRevocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='revoked', full_name='zsearch.CertificateRevocation.revoked', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='zsearch.CertificateRevocation.reason', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=963,
)


_CERTIFICATEAUDIT = _descriptor.Descriptor(
  name='CertificateAudit',
  full_name='zsearch.CertificateAudit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mozilla', full_name='zsearch.CertificateAudit.mozilla', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1034,
)


_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='zsearch.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha1fp', full_name='zsearch.Certificate.sha1fp', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sha256fp', full_name='zsearch.Certificate.sha256fp', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raw', full_name='zsearch.Certificate.raw', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parsed', full_name='zsearch.Certificate.parsed', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parse_status', full_name='zsearch.Certificate.parse_status', index=4,
      number=44, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parse_version', full_name='zsearch.Certificate.parse_version', index=5,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parse_error', full_name='zsearch.Certificate.parse_error', index=6,
      number=47, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parents', full_name='zsearch.Certificate.parents', index=7,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='presented_chain', full_name='zsearch.Certificate.presented_chain', index=8,
      number=45, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='zsearch.Certificate.source', index=9,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seen_in_scan', full_name='zsearch.Certificate.seen_in_scan', index=10,
      number=29, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='post_processed', full_name='zsearch.Certificate.post_processed', index=11,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='post_process_timestamp', full_name='zsearch.Certificate.post_process_timestamp', index=12,
      number=37, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='validation', full_name='zsearch.Certificate.validation', index=13,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ct', full_name='zsearch.Certificate.ct', index=14,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='zlint', full_name='zsearch.Certificate.zlint', index=15,
      number=38, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revocation', full_name='zsearch.Certificate.revocation', index=16,
      number=43, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audit', full_name='zsearch.Certificate.audit', index=17,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_precert', full_name='zsearch.Certificate.is_precert', index=18,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='not_valid_after', full_name='zsearch.Certificate.not_valid_after', index=19,
      number=41, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='not_valid_before', full_name='zsearch.Certificate.not_valid_before', index=20,
      number=42, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_nss', full_name='zsearch.Certificate.in_nss', index=21,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_microsoft', full_name='zsearch.Certificate.in_microsoft', index=22,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='in_apple', full_name='zsearch.Certificate.in_apple', index=23,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='validation_timestamp', full_name='zsearch.Certificate.validation_timestamp', index=24,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='valid_nss', full_name='zsearch.Certificate.valid_nss', index=25,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='valid_microsoft', full_name='zsearch.Certificate.valid_microsoft', index=26,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='valid_apple', full_name='zsearch.Certificate.valid_apple', index=27,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_valid_nss', full_name='zsearch.Certificate.was_valid_nss', index=28,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='was_valid_microsoft', full_name='zsearch.Certificate.was_valid_microsoft', index=29,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_valid_apple', full_name='zsearch.Certificate.was_valid_apple', index=30,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_in_nss', full_name='zsearch.Certificate.was_in_nss', index=31,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_in_microsoft', full_name='zsearch.Certificate.was_in_microsoft', index=32,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='was_in_apple', full_name='zsearch.Certificate.was_in_apple', index=33,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='current_valid_nss', full_name='zsearch.Certificate.current_valid_nss', index=34,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_valid_microsoft', full_name='zsearch.Certificate.current_valid_microsoft', index=35,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='current_valid_apple', full_name='zsearch.Certificate.current_valid_apple', index=36,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='current_in_nss', full_name='zsearch.Certificate.current_in_nss', index=37,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='current_in_microsoft', full_name='zsearch.Certificate.current_in_microsoft', index=38,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='current_in_apple', full_name='zsearch.Certificate.current_in_apple', index=39,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='nss_audit', full_name='zsearch.Certificate.nss_audit', index=40,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='should_post_process', full_name='zsearch.Certificate.should_post_process', index=41,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
    _descriptor.FieldDescriptor(
      name='do_not_post_process', full_name='zsearch.Certificate.do_not_post_process', index=42,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=2299,
)

_ROOTSTORESTATUS.fields_by_name['type'].enum_type = _CERTIFICATETYPE
_CERTIFICATEVALIDATION.fields_by_name['nss'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['microsoft'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['apple'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['java'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['android'].message_type = _ROOTSTORESTATUS
_CERTIFICATEVALIDATION.fields_by_name['google_ct_primary'].message_type = _ROOTSTORESTATUS
_CERTIFICATEREVOCATION.fields_by_name['reason'].enum_type = _CERTIFICATEREVOCATIONREASON
_CERTIFICATEAUDIT.fields_by_name['mozilla'].message_type = _MOZILLASALESFORCESTATUS
_CERTIFICATE.fields_by_name['parse_status'].enum_type = _CERTIFICATEPARSESTATUS
_CERTIFICATE.fields_by_name['source'].enum_type = _CERTIFICATESOURCE
_CERTIFICATE.fields_by_name['validation'].message_type = _CERTIFICATEVALIDATION
_CERTIFICATE.fields_by_name['ct'].message_type = ct__pb2._CTSTATUS
_CERTIFICATE.fields_by_name['zlint'].message_type = zlint__pb2._ZLINT
_CERTIFICATE.fields_by_name['revocation'].message_type = _CERTIFICATEREVOCATION
_CERTIFICATE.fields_by_name['audit'].message_type = _CERTIFICATEAUDIT
_CERTIFICATE.fields_by_name['nss_audit'].message_type = _MOZILLASALESFORCESTATUS
DESCRIPTOR.message_types_by_name['RootStoreStatus'] = _ROOTSTORESTATUS
DESCRIPTOR.message_types_by_name['CertificateValidation'] = _CERTIFICATEVALIDATION
DESCRIPTOR.message_types_by_name['MozillaSalesForceStatus'] = _MOZILLASALESFORCESTATUS
DESCRIPTOR.message_types_by_name['CertificateRevocation'] = _CERTIFICATEREVOCATION
DESCRIPTOR.message_types_by_name['CertificateAudit'] = _CERTIFICATEAUDIT
DESCRIPTOR.message_types_by_name['Certificate'] = _CERTIFICATE
DESCRIPTOR.enum_types_by_name['CertificateType'] = _CERTIFICATETYPE
DESCRIPTOR.enum_types_by_name['CertificateSource'] = _CERTIFICATESOURCE
DESCRIPTOR.enum_types_by_name['CertificateParseStatus'] = _CERTIFICATEPARSESTATUS
DESCRIPTOR.enum_types_by_name['CertificateRevocationReason'] = _CERTIFICATEREVOCATIONREASON

RootStoreStatus = _reflection.GeneratedProtocolMessageType('RootStoreStatus', (_message.Message,), dict(
  DESCRIPTOR = _ROOTSTORESTATUS,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.RootStoreStatus)
  ))
_sym_db.RegisterMessage(RootStoreStatus)

CertificateValidation = _reflection.GeneratedProtocolMessageType('CertificateValidation', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEVALIDATION,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CertificateValidation)
  ))
_sym_db.RegisterMessage(CertificateValidation)

MozillaSalesForceStatus = _reflection.GeneratedProtocolMessageType('MozillaSalesForceStatus', (_message.Message,), dict(
  DESCRIPTOR = _MOZILLASALESFORCESTATUS,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.MozillaSalesForceStatus)
  ))
_sym_db.RegisterMessage(MozillaSalesForceStatus)

CertificateRevocation = _reflection.GeneratedProtocolMessageType('CertificateRevocation', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEREVOCATION,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CertificateRevocation)
  ))
_sym_db.RegisterMessage(CertificateRevocation)

CertificateAudit = _reflection.GeneratedProtocolMessageType('CertificateAudit', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEAUDIT,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.CertificateAudit)
  ))
_sym_db.RegisterMessage(CertificateAudit)

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATE,
  __module__ = 'certificate_pb2'
  # @@protoc_insertion_point(class_scope:zsearch.Certificate)
  ))
_sym_db.RegisterMessage(Certificate)


_CERTIFICATE.fields_by_name['in_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['in_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['in_apple'].has_options = True
_CERTIFICATE.fields_by_name['in_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['valid_nss'].has_options = True
_CERTIFICATE.fields_by_name['valid_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['valid_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['valid_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['valid_apple'].has_options = True
_CERTIFICATE.fields_by_name['valid_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_valid_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['was_valid_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_valid_apple'].has_options = True
_CERTIFICATE.fields_by_name['was_valid_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_in_nss'].has_options = True
_CERTIFICATE.fields_by_name['was_in_nss']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_in_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['was_in_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['was_in_apple'].has_options = True
_CERTIFICATE.fields_by_name['was_in_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['current_valid_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['current_valid_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['current_valid_apple'].has_options = True
_CERTIFICATE.fields_by_name['current_valid_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['current_in_microsoft'].has_options = True
_CERTIFICATE.fields_by_name['current_in_microsoft']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['current_in_apple'].has_options = True
_CERTIFICATE.fields_by_name['current_in_apple']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['nss_audit'].has_options = True
_CERTIFICATE.fields_by_name['nss_audit']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['should_post_process'].has_options = True
_CERTIFICATE.fields_by_name['should_post_process']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_CERTIFICATE.fields_by_name['do_not_post_process'].has_options = True
_CERTIFICATE.fields_by_name['do_not_post_process']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc
from grpc.framework.common import cardinality
from grpc.framework.interfaces.face import utilities as face_utilities

import anonstore_pb2 as anonstore__pb2
import hoststore_pb2 as hoststore__pb2
import rpc_pb2 as rpc__pb2


class AdminServiceStub(object):
  """Two gRPC interfaces. One from

  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Shutdown = channel.unary_unary(
        '/zsearch.AdminService/Shutdown',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.Status = channel.unary_unary(
        '/zsearch.AdminService/Status',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.Statistics = channel.unary_unary(
        '/zsearch.AdminService/Statistics',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.PruneIPv4 = channel.unary_unary(
        '/zsearch.AdminService/PruneIPv4',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.PruneDomain = channel.unary_unary(
        '/zsearch.AdminService/PruneDomain',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.UpdateASData = channel.unary_unary(
        '/zsearch.AdminService/UpdateASData',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.UpdateLocationData = channel.unary_unary(
        '/zsearch.AdminService/UpdateLocationData',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.ValidateCertificates = channel.unary_unary(
        '/zsearch.AdminService/ValidateCertificates',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.FixCertificateSource = channel.unary_unary(
        '/zsearch.AdminService/FixCertificateSource',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.DumpIPv4ToJSON = channel.unary_unary(
        '/zsearch.AdminService/DumpIPv4ToJSON',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.DumpDomainToJSON = channel.unary_unary(
        '/zsearch.AdminService/DumpDomainToJSON',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.DumpCertificatesToJSON = channel.unary_unary(
        '/zsearch.AdminService/DumpCertificatesToJSON',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.DumpKeysToJSON = channel.unary_unary(
        '/zsearch.AdminService/DumpKeysToJSON',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.RegenerateIPv4Deltas = channel.unary_unary(
        '/zsearch.AdminService/RegenerateIPv4Deltas',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.RegenerateDomainDeltas = channel.unary_unary(
        '/zsearch.AdminService/RegenerateDomainDeltas',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.RegenerateCertificateDeltas = channel.unary_unary(
        '/zsearch.AdminService/RegenerateCertificateDeltas',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.RegenerateSingleCertificateDelta = channel.unary_unary(
        '/zsearch.AdminService/RegenerateSingleCertificateDelta',
        request_serializer=rpc__pb2.AnonymousQuery.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.ReprocessCertificates = channel.unary_unary(
        '/zsearch.AdminService/ReprocessCertificates',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.ReprocessSingleCertificate = channel.unary_unary(
        '/zsearch.AdminService/ReprocessSingleCertificate',
        request_serializer=rpc__pb2.AnonymousQuery.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.Ping = channel.unary_unary(
        '/zsearch.AdminService/Ping',
        request_serializer=rpc__pb2.Command.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )


class AdminServiceServicer(object):
  """Two gRPC interfaces. One from

  """

  def Shutdown(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Status(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Statistics(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PruneIPv4(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PruneDomain(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateASData(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateLocationData(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ValidateCertificates(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FixCertificateSource(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DumpIPv4ToJSON(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DumpDomainToJSON(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DumpCertificatesToJSON(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DumpKeysToJSON(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegenerateIPv4Deltas(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegenerateDomainDeltas(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegenerateCertificateDeltas(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RegenerateSingleCertificateDelta(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ReprocessCertificates(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ReprocessSingleCertificate(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Ping(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdminServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Shutdown': grpc.unary_unary_rpc_method_handler(
          servicer.Shutdown,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'Status': grpc.unary_unary_rpc_method_handler(
          servicer.Status,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'Statistics': grpc.unary_unary_rpc_method_handler(
          servicer.Statistics,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'PruneIPv4': grpc.unary_unary_rpc_method_handler(
          servicer.PruneIPv4,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'PruneDomain': grpc.unary_unary_rpc_method_handler(
          servicer.PruneDomain,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'UpdateASData': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateASData,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'UpdateLocationData': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateLocationData,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'ValidateCertificates': grpc.unary_unary_rpc_method_handler(
          servicer.ValidateCertificates,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'FixCertificateSource': grpc.unary_unary_rpc_method_handler(
          servicer.FixCertificateSource,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'DumpIPv4ToJSON': grpc.unary_unary_rpc_method_handler(
          servicer.DumpIPv4ToJSON,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'DumpDomainToJSON': grpc.unary_unary_rpc_method_handler(
          servicer.DumpDomainToJSON,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'DumpCertificatesToJSON': grpc.unary_unary_rpc_method_handler(
          servicer.DumpCertificatesToJSON,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'DumpKeysToJSON': grpc.unary_unary_rpc_method_handler(
          servicer.DumpKeysToJSON,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'RegenerateIPv4Deltas': grpc.unary_unary_rpc_method_handler(
          servicer.RegenerateIPv4Deltas,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'RegenerateDomainDeltas': grpc.unary_unary_rpc_method_handler(
          servicer.RegenerateDomainDeltas,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'RegenerateCertificateDeltas': grpc.unary_unary_rpc_method_handler(
          servicer.RegenerateCertificateDeltas,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'RegenerateSingleCertificateDelta': grpc.unary_unary_rpc_method_handler(
          servicer.RegenerateSingleCertificateDelta,
          request_deserializer=rpc__pb2.AnonymousQuery.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'ReprocessCertificates': grpc.unary_unary_rpc_method_handler(
          servicer.ReprocessCertificates,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'ReprocessSingleCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.ReprocessSingleCertificate,
          request_deserializer=rpc__pb2.AnonymousQuery.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'Ping': grpc.unary_unary_rpc_method_handler(
          servicer.Ping,
          request_deserializer=rpc__pb2.Command.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'zsearch.AdminService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


class QueryServiceStub(object):

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetHostIPv4Record = channel.unary_unary(
        '/zsearch.QueryService/GetHostIPv4Record',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=rpc__pb2.HostQueryResponse.FromString,
        )
    self.PutHostIPv4Record = channel.unary_unary(
        '/zsearch.QueryService/PutHostIPv4Record',
        request_serializer=hoststore__pb2.Record.SerializeToString,
        response_deserializer=hoststore__pb2.Delta.FromString,
        )
    self.DelHostIPv4Record = channel.unary_unary(
        '/zsearch.QueryService/DelHostIPv4Record',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=hoststore__pb2.Delta.FromString,
        )
    self.GetAllIPv4Records = channel.unary_unary(
        '/zsearch.QueryService/GetAllIPv4Records',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=rpc__pb2.HostQueryResponse.FromString,
        )
    self.GetHostIPv4Delta = channel.unary_unary(
        '/zsearch.QueryService/GetHostIPv4Delta',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=hoststore__pb2.Delta.FromString,
        )
    self.GetHostDomainRecord = channel.unary_unary(
        '/zsearch.QueryService/GetHostDomainRecord',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=rpc__pb2.HostQueryResponse.FromString,
        )
    self.PutHostDomainRecord = channel.unary_unary(
        '/zsearch.QueryService/PutHostDomainRecord',
        request_serializer=hoststore__pb2.Record.SerializeToString,
        response_deserializer=hoststore__pb2.Delta.FromString,
        )
    self.DelHostDomainRecord = channel.unary_unary(
        '/zsearch.QueryService/DelHostDomainRecord',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=hoststore__pb2.Delta.FromString,
        )
    self.GetAllDomainRecords = channel.unary_unary(
        '/zsearch.QueryService/GetAllDomainRecords',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=rpc__pb2.HostQueryResponse.FromString,
        )
    self.GetHostDomainDelta = channel.unary_unary(
        '/zsearch.QueryService/GetHostDomainDelta',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=hoststore__pb2.Delta.FromString,
        )
    self.GetCertificate = channel.unary_unary(
        '/zsearch.QueryService/GetCertificate',
        request_serializer=rpc__pb2.AnonymousQuery.SerializeToString,
        response_deserializer=rpc__pb2.AnonymousQueryResponse.FromString,
        )
    self.UpsertCertificate = channel.unary_unary(
        '/zsearch.QueryService/UpsertCertificate',
        request_serializer=anonstore__pb2.AnonymousRecord.SerializeToString,
        response_deserializer=anonstore__pb2.AnonymousDelta.FromString,
        )
    self.UpsertRawCertificate = channel.unary_unary(
        '/zsearch.QueryService/UpsertRawCertificate',
        request_serializer=anonstore__pb2.AnonymousRecord.SerializeToString,
        response_deserializer=anonstore__pb2.AnonymousDelta.FromString,
        )
    self.GetCryptographicKey = channel.unary_unary(
        '/zsearch.QueryService/GetCryptographicKey',
        request_serializer=rpc__pb2.AnonymousQuery.SerializeToString,
        response_deserializer=rpc__pb2.AnonymousQueryResponse.FromString,
        )
    self.UpsertCryptographicKey = channel.unary_unary(
        '/zsearch.QueryService/UpsertCryptographicKey',
        request_serializer=anonstore__pb2.AnonymousRecord.SerializeToString,
        response_deserializer=anonstore__pb2.AnonymousDelta.FromString,
        )
    self.GetPublicLocation = channel.unary_unary(
        '/zsearch.QueryService/GetPublicLocation',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=hoststore__pb2.LocationAtom.FromString,
        )
    self.GetRestrictedLocation = channel.unary_unary(
        '/zsearch.QueryService/GetRestrictedLocation',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=hoststore__pb2.LocationAtom.FromString,
        )
    self.GetWHOIS = channel.unary_unary(
        '/zsearch.QueryService/GetWHOIS',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=hoststore__pb2.Record.FromString,
        )
    self.GetUserMetadata = channel.unary_unary(
        '/zsearch.QueryService/GetUserMetadata',
        request_serializer=rpc__pb2.HostQuery.SerializeToString,
        response_deserializer=hoststore__pb2.Record.FromString,
        )
    self.PutUserMetadata = channel.unary_unary(
        '/zsearch.QueryService/PutUserMetadata',
        request_serializer=hoststore__pb2.Record.SerializeToString,
        response_deserializer=rpc__pb2.CommandReply.FromString,
        )
    self.GetRootStore = channel.unary_unary(
        '/zsearch.QueryService/GetRootStore',
        request_serializer=rpc__pb2.RootStoreQuery.SerializeToString,
        response_deserializer=rpc__pb2.RootStoreReply.FromString,
        )


class QueryServiceServicer(object):

  def GetHostIPv4Record(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PutHostIPv4Record(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DelHostIPv4Record(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAllIPv4Records(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetHostIPv4Delta(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetHostDomainRecord(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PutHostDomainRecord(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DelHostDomainRecord(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAllDomainRecords(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetHostDomainDelta(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetCertificate(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpsertCertificate(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpsertRawCertificate(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetCryptographicKey(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpsertCryptographicKey(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetPublicLocation(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetRestrictedLocation(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetWHOIS(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetUserMetadata(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PutUserMetadata(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetRootStore(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_QueryServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetHostIPv4Record': grpc.unary_unary_rpc_method_handler(
          servicer.GetHostIPv4Record,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=rpc__pb2.HostQueryResponse.SerializeToString,
      ),
      'PutHostIPv4Record': grpc.unary_unary_rpc_method_handler(
          servicer.PutHostIPv4Record,
          request_deserializer=hoststore__pb2.Record.FromString,
          response_serializer=hoststore__pb2.Delta.SerializeToString,
      ),
      'DelHostIPv4Record': grpc.unary_unary_rpc_method_handler(
          servicer.DelHostIPv4Record,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=hoststore__pb2.Delta.SerializeToString,
      ),
      'GetAllIPv4Records': grpc.unary_unary_rpc_method_handler(
          servicer.GetAllIPv4Records,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=rpc__pb2.HostQueryResponse.SerializeToString,
      ),
      'GetHostIPv4Delta': grpc.unary_unary_rpc_method_handler(
          servicer.GetHostIPv4Delta,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=hoststore__pb2.Delta.SerializeToString,
      ),
      'GetHostDomainRecord': grpc.unary_unary_rpc_method_handler(
          servicer.GetHostDomainRecord,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=rpc__pb2.HostQueryResponse.SerializeToString,
      ),
      'PutHostDomainRecord': grpc.unary_unary_rpc_method_handler(
          servicer.PutHostDomainRecord,
          request_deserializer=hoststore__pb2.Record.FromString,
          response_serializer=hoststore__pb2.Delta.SerializeToString,
      ),
      'DelHostDomainRecord': grpc.unary_unary_rpc_method_handler(
          servicer.DelHostDomainRecord,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=hoststore__pb2.Delta.SerializeToString,
      ),
      'GetAllDomainRecords': grpc.unary_unary_rpc_method_handler(
          servicer.GetAllDomainRecords,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=rpc__pb2.HostQueryResponse.SerializeToString,
      ),
      'GetHostDomainDelta': grpc.unary_unary_rpc_method_handler(
          servicer.GetHostDomainDelta,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=hoststore__pb2.Delta.SerializeToString,
      ),
      'GetCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.GetCertificate,
          request_deserializer=rpc__pb2.AnonymousQuery.FromString,
          response_serializer=rpc__pb2.AnonymousQueryResponse.SerializeToString,
      ),
      'UpsertCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.UpsertCertificate,
          request_deserializer=anonstore__pb2.AnonymousRecord.FromString,
          response_serializer=anonstore__pb2.AnonymousDelta.SerializeToString,
      ),
      'UpsertRawCertificate': grpc.unary_unary_rpc_method_handler(
          servicer.UpsertRawCertificate,
          request_deserializer=anonstore__pb2.AnonymousRecord.FromString,
          response_serializer=anonstore__pb2.AnonymousDelta.SerializeToString,
      ),
      'GetCryptographicKey': grpc.unary_unary_rpc_method_handler(
          servicer.GetCryptographicKey,
          request_deserializer=rpc__pb2.AnonymousQuery.FromString,
          response_serializer=rpc__pb2.AnonymousQueryResponse.SerializeToString,
      ),
      'UpsertCryptographicKey': grpc.unary_unary_rpc_method_handler(
          servicer.UpsertCryptographicKey,
          request_deserializer=anonstore__pb2.AnonymousRecord.FromString,
          response_serializer=anonstore__pb2.AnonymousDelta.SerializeToString,
      ),
      'GetPublicLocation': grpc.unary_unary_rpc_method_handler(
          servicer.GetPublicLocation,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=hoststore__pb2.LocationAtom.SerializeToString,
      ),
      'GetRestrictedLocation': grpc.unary_unary_rpc_method_handler(
          servicer.GetRestrictedLocation,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=hoststore__pb2.LocationAtom.SerializeToString,
      ),
      'GetWHOIS': grpc.unary_unary_rpc_method_handler(
          servicer.GetWHOIS,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=hoststore__pb2.Record.SerializeToString,
      ),
      'GetUserMetadata': grpc.unary_unary_rpc_method_handler(
          servicer.GetUserMetadata,
          request_deserializer=rpc__pb2.HostQuery.FromString,
          response_serializer=hoststore__pb2.Record.SerializeToString,
      ),
      'PutUserMetadata': grpc.unary_unary_rpc_method_handler(
          servicer.PutUserMetadata,
          request_deserializer=hoststore__pb2.Record.FromString,
          response_serializer=rpc__pb2.CommandReply.SerializeToString,
      ),
      'GetRootStore': grpc.unary_unary_rpc_method_handler(
          servicer.GetRootStore,
          request_deserializer=rpc__pb2.RootStoreQuery.FromString,
          response_serializer=rpc__pb2.RootStoreReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'zsearch.QueryService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
